summaryrefslogtreecommitdiff
path: root/epan/packet.c
diff options
context:
space:
mode:
authorGuy Harris <guy@alum.mit.edu>2017-04-16 18:48:30 -0700
committerGuy Harris <guy@alum.mit.edu>2017-04-17 01:49:01 +0000
commit407a2b07e55a262905881c7d1e225d618e9824fb (patch)
treeff273d3ca4dc747c9dc397244a04d90872c3b4d0 /epan/packet.c
parent1bfc8580e322450f8afaaf797e236469b948c984 (diff)
downloadwireshark-407a2b07e55a262905881c7d1e225d618e9824fb.tar.gz
Rename some routines and structure members.
They deal with sets of hfids, which can belong to protocols as well as fields (I guess you could argue that a protocol is a field, but...). Change-Id: Ibd103cfa26427ead4ef54be89f1251908004cfae Reviewed-on: https://code.wireshark.org/review/21154 Reviewed-by: Guy Harris <guy@alum.mit.edu>
Diffstat (limited to 'epan/packet.c')
-rw-r--r--epan/packet.c24
1 files changed, 12 insertions, 12 deletions
diff --git a/epan/packet.c b/epan/packet.c
index bb43449d7f..5a62a1cbf6 100644
--- a/epan/packet.c
+++ b/epan/packet.c
@@ -133,7 +133,7 @@ static GSList *postseq_cleanup_routines;
*/
typedef struct {
dissector_handle_t handle;
- GArray *wanted_fields;
+ GArray *wanted_hfids;
} postdissector;
/*
@@ -3274,12 +3274,12 @@ register_postdissector(dissector_handle_t handle)
postdissectors = g_array_sized_new(FALSE, FALSE, (guint)sizeof(postdissector), 1);
p.handle = handle;
- p.wanted_fields = NULL;
+ p.wanted_hfids = NULL;
postdissectors = g_array_append_val(postdissectors, p);
}
void
-set_postdissector_wanted_fields(dissector_handle_t handle, GArray *wanted_fields)
+set_postdissector_wanted_hfids(dissector_handle_t handle, GArray *wanted_hfids)
{
guint i;
@@ -3287,7 +3287,7 @@ set_postdissector_wanted_fields(dissector_handle_t handle, GArray *wanted_fields
for (i = 0; i < postdissectors->len; i++) {
if (POSTDISSECTORS(i).handle == handle) {
- POSTDISSECTORS(i).wanted_fields = wanted_fields;
+ POSTDISSECTORS(i).wanted_hfids = wanted_hfids;
break;
}
}
@@ -3338,34 +3338,34 @@ call_all_postdissectors(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
}
gboolean
-postdissectors_want_fields(void)
+postdissectors_want_hfids(void)
{
guint i;
for (i = 0; i < postdissectors->len; i++) {
- if (POSTDISSECTORS(i).wanted_fields != NULL &&
- POSTDISSECTORS(i).wanted_fields->len != 0)
+ if (POSTDISSECTORS(i).wanted_hfids != NULL &&
+ POSTDISSECTORS(i).wanted_hfids->len != 0)
return TRUE;
}
return FALSE;
}
void
-prime_epan_dissect_with_postdissector_wanted_fields(epan_dissect_t *edt)
+prime_epan_dissect_with_postdissector_wanted_hfids(epan_dissect_t *edt)
{
guint i;
if (postdissectors == NULL) {
/*
* No postdissector expressed an interest in any fields.
*/
return;
}
for (i = 0; i < postdissectors->len; i++) {
- if (POSTDISSECTORS(i).wanted_fields != NULL &&
- POSTDISSECTORS(i).wanted_fields->len != 0)
+ if (POSTDISSECTORS(i).wanted_hfids != NULL &&
+ POSTDISSECTORS(i).wanted_hfids->len != 0)
epan_dissect_prime_with_hfid_array(edt,
- POSTDISSECTORS(i).wanted_fields);
+ POSTDISSECTORS(i).wanted_hfids);
}
}
@@ -3338,34 +3338,34 @@ call_all_postdissectors(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
if (postdissectors == NULL) {
/*
- * No postdissector expressed an interest in any fields.
+ * No postdissector expressed an interest in any hfids.
*/
return;